@@ -1,7 +1,7 @@
 #' Update a historical table
 #'
 #' @description
-#'   `update_snapshots` makes it easy to create and update a historical data table on a remote (SQL) server.
+#'   `update_snapshot()` makes it easy to create and update a historical data table on a remote (SQL) server.
 #'   The function takes the data (`.data`) as it looks on a given point in time (`timestamp`) and then updates
 #'   (or creates) an remote table identified by `db_table`.
 #'   This update only stores the changes between the new data (`.data`) and the data currently stored on the remote.
@@ -9,6 +9,16 @@
 #'
 #'   See `vignette("basic-principles")` for further introduction to the function.
 #'
+#' @details
+#'   The most common use case is having consecutive snapshots of a dataset and wanting to store the changes between
+#'   them. If you have a special case where you want to insert data that is not consecutive, you can set the
+#'   `enforce_chronological_order` to `FALSE`. This will allow you to insert data that is earlier than the latest
+#'   time stamp.
+#'
+#'   If you have more updates in a single day and use `Date()` rather than `POSIXct()`, as your time stamp, you
+#'   may end up with records where `from_ts` and `until_ts` are equal. These records not normally accessible with
+#'   `get_table()` and you may want to prevent these records using `collapse_continuous_records = TRUE`.
+#'
 #' @template .data
 #' @template conn
 #' @template db_table
@@ -24,6 +34,9 @@
 #'   A configured logging object. If none is given, one is initialized with default arguments.
 #' @param enforce_chronological_order (`logical(1)`)\cr
 #'   Are updates allowed if they are chronologically earlier than latest update?
+#' @param collapse_continuous_records (`logical(1)`)\cr
+#'   Check for records where from/until time stamps are equal and delete?
+#'   Forced `TRUE` when `enforce_chronological_order` is `FALSE`.
 #' @return
 #'   No return value, called for side effects.
 #' @examplesIf requireNamespace("RSQLite", quietly = TRUE)
@@ -55,7 +68,8 @@
 #' @export
 update_snapshot <- function(.data, conn, db_table, timestamp, filters = NULL, message = NULL, tic = Sys.time(),
                             logger = NULL,
-                            enforce_chronological_order = TRUE) {
+                            enforce_chronological_order = TRUE,
+                            collapse_continuous_records = FALSE) {
 
   # Check arguments
   checkmate::assert_class(.data, "tbl_dbi")
@@ -67,6 +81,7 @@ update_snapshot <- function(.data, conn, db_table, timestamp, filters = NULL, me
   assert_timestamp_like(tic)
   checkmate::assert_multi_class(logger, "Logger", null.ok = TRUE)
   checkmate::assert_logical(enforce_chronological_order)
+  checkmate::assert_logical(collapse_continuous_records)
 
 
   ### Create target table if not exists
@@ -76,7 +91,7 @@ update_snapshot <- function(.data, conn, db_table, timestamp, filters = NULL, me
   if (table_exists(conn, db_table_id)) {
     # Obtain a lock on the table
     if (!lock_table(conn, db_table_id, schema = get_schema(db_table_id))) {
-      stop("A lock could not be obtained on the table")
+      stop("A lock could not be obtained on the table", call. = FALSE)
     }
 
     db_table <- dplyr::tbl(conn, db_table_id)
@@ -168,22 +183,23 @@ update_snapshot <- function(.data, conn, db_table, timestamp, filters = NULL, me
 
   # Copy to the target connection if needed
   if (!identical(dbplyr::remote_con(.data), conn)) {
-    .data <- dplyr::copy_to(conn, .data, name = unique_table_name())
+    .data <- dplyr::copy_to(conn, .data, name = unique_table_name("SCDB_update_snapshot_input"))
     defer_db_cleanup(.data)
   }
 
   # Once we ensure .data is on the same connection as the target, we compute the checksums
-  .data <- dplyr::compute(digest_to_checksum(.data, col = "checksum"))
+  .data <- digest_to_checksum(.data, col = "checksum")
+  if (!inherits(conn, "SQLiteConnection")) .data <- dplyr::compute(.data) # SQLite was computed in digest_to_checksum
   defer_db_cleanup(.data)
 
   ### Determine the next timestamp in the data (can be NA if none is found)
   next_timestamp <- min(
     db_table %>%
-      dplyr::filter(.data$from_ts  > timestamp) %>%
+      dplyr::filter(.data$from_ts > !!db_timestamp(timestamp, conn)) %>%
       dplyr::summarize(next_timestamp = min(.data$from_ts, na.rm = TRUE)) %>%
       dplyr::pull("next_timestamp"),
     db_table %>%
-      dplyr::filter(.data$until_ts > timestamp) %>%
+      dplyr::filter(.data$until_ts > !!db_timestamp(timestamp, conn)) %>%
       dplyr::summarize(next_timestamp = min(.data$until_ts, na.rm = TRUE)) %>%
       dplyr::pull("next_timestamp")
   ) %>%
@@ -193,11 +209,11 @@ update_snapshot <- function(.data, conn, db_table, timestamp, filters = NULL, me
 
 
   ### Consider only records valid at timestamp (and apply the filter if present)
-  db_table <- slice_time(db_table, timestamp)
+  db_table <- slice_time(db_table, db_timestamp(timestamp, conn))
 
   # Apply filter to current records
   if (!is.null(filters) && !identical(dbplyr::remote_con(filters), conn)) {
-    filters <- dplyr::copy_to(conn, filters, name = unique_table_name())
+    filters <- dplyr::copy_to(conn, filters, name = unique_table_name("SCDB_update_snapshot_filter"))
     defer_db_cleanup(filters)
   }
   db_table <- filter_keys(db_table, filters)
@@ -330,22 +346,24 @@ update_snapshot <- function(.data, conn, db_table, timestamp, filters = NULL, me
   # If several updates come in a single day, some records may have from_ts = until_ts.
   # Alternatively, the above handling of consecutive records will make records have from_ts = until_ts
   # We remove these records here
-  redundant_rows <- dplyr::tbl(conn, db_table_id) %>%
-    dplyr::filter(.data$from_ts == .data$until_ts) %>%
-    dplyr::select("checksum", "from_ts")
+  if (collapse_continuous_records || !enforce_chronological_order) {
+    redundant_rows <- dplyr::tbl(conn, db_table_id) %>%
+      dplyr::filter(.data$from_ts == .data$until_ts) %>%
+      dplyr::select("checksum", "from_ts")
 
-  sql_fix_redundant <- dbplyr::sql_query_delete(
-    con = conn,
-    table = dbplyr::as.sql(db_table_id, con = conn),
-    from = dbplyr::sql_render(redundant_rows),
-    by = c("checksum", "from_ts")
-  )
+    sql_fix_redundant <- dbplyr::sql_query_delete(
+      con = conn,
+      table = dbplyr::as.sql(db_table_id, con = conn),
+      from = dbplyr::sql_render(redundant_rows),
+      by = c("checksum", "from_ts")
+    )
 
-  # Commit changes to DB
-  rs_fix_redundant <- DBI::dbSendQuery(conn, sql_fix_redundant)
-  n_redundant <- DBI::dbGetRowsAffected(rs_fix_redundant) / 2
-  DBI::dbClearResult(rs_fix_redundant)
-  logger$log_info("Continuous records collapsed:", n_redundant)
+    # Commit changes to DB
+    rs_fix_redundant <- DBI::dbSendQuery(conn, sql_fix_redundant)
+    n_redundant <- DBI::dbGetRowsAffected(rs_fix_redundant) / 2
+    DBI::dbClearResult(rs_fix_redundant)
+    logger$log_info("Continuous records collapsed:", n_redundant)
+  }
 
 
   # Clean up
